Hyperion Developer Guide
==================================

Documentation specific for the Hyperion module within MX-Bluesky

.. grid:: 2
    :gutter: 2

    .. grid-item-card:: :material-regular:`description;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

            reference/param-hierarchy
            reference/readme
            deploying-hyperion
            system-tests

        +++

        Technical reference material on standards in use.

    .. grid-item-card:: :material-regular:`task;3em`

        .. toctree::
            :caption: How-to Guides
            :maxdepth: 1

            how-to/update-panda-ioc

        +++

        Practical step-by-step guides for day-to-day dev tasks.
